==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebFilteringExpressionsTreeOrFilteringExpressionDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebFilteringExpressionsTreeOrFilteringExpressionDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebFilteringExpressionsTreeOrFilteringExpressionDescription, _super);
    function WebFilteringExpressionsTreeOrFilteringExpressionDescription() {
        return _super.call(this) || this;
    }
    WebFilteringExpressionsTreeOrFilteringExpressionDescription.prototype.get_type = function () {
        return "WebFilteringExpressionsTreeOrFilteringExpression";
    };
    Object.defineProperty(WebFilteringExpressionsTreeOrFilteringExpressionDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    WebFilteringExpressionsTreeOrFilteringExpressionDescription.$t = markType(WebFilteringExpressionsTreeOrFilteringExpressionDescription, 'WebFilteringExpressionsTreeOrFilteringExpressionDescription', Description.$);
    return WebFilteringExpressionsTreeOrFilteringExpressionDescription;
}(Description));
export { WebFilteringExpressionsTreeOrFilteringExpressionDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebFilteringExpressionsTreeOrFilteringExpressionDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { WebExpressionTreeOrFilteringExpressionDescription } from "./WebExpressionTreeOrFilteringExpressionDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebFilteringExpressionsTreeOrFilteringExpressionDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFilteringExpressionsTreeOrFilteringExpressionDescription, _super);
    function WebFilteringExpressionsTreeOrFilteringExpressionDescription() {
        return _super.call(this) || this;
    }
    WebFilteringExpressionsTreeOrFilteringExpressionDescription.prototype.get_type = function () {
        return "WebFilteringExpressionsTreeOrFilteringExpression";
    };
    WebFilteringExpressionsTreeOrFilteringExpressionDescription.$t = markType(WebFilteringExpressionsTreeOrFilteringExpressionDescription, 'WebFilteringExpressionsTreeOrFilteringExpressionDescription', WebExpressionTreeOrFilteringExpressionDescription.$);
    return WebFilteringExpressionsTreeOrFilteringExpressionDescription;
}(WebExpressionTreeOrFilteringExpressionDescription));
export { WebFilteringExpressionsTreeOrFilteringExpressionDescription };
